@@ -25,12 +25,14 @@
 # **************************************************************************
 
 import os
-import pwem
 
+import pwem
 from pyworkflow.utils import Environ
 
 from cryoef.constants import CRYOEF_HOME, V1_1_0
 
+
+__version__ = '3.0.13'
 _logo = "cryoEF_logo.png"
 _references = ['Naydenova2017']
 
@@ -39,6 +41,7 @@ class Plugin(pwem.Plugin):
     _homeVar = CRYOEF_HOME
     _pathVars = [CRYOEF_HOME]
     _supportedVersions = [V1_1_0]
+    _url = "https://github.com/scipion-em/scipion-em-cryoef"
 
     @classmethod
     def _defineVariables(cls):
